@@ -1,6 +1,6 @@
 package SPVM::Net::SSLeay;
 
-our $VERSION = "0.034001";
+our $VERSION = "0.035";
 
 1;
 
@@ -250,6 +250,8 @@ Exceptions:
 
 The output reference $out_ref must be 1-length array. Otherwise an exception is thrown.
 
+The reference of the output length $outlen_ref must be defined. Otherwise an exception is thrown.
+
 $server must be defined. Otherwise an exception is thrown.
 
 $client must be defined. Otherwise an exception is thrown.
@@ -534,6 +536,8 @@ Exceptions:
 
 The data reference $data_ref must be 1-length array. Otherwise an exception is thrown.
 
+The reference of the length $len_ref must be defined. Otherwise an exception is thrown.
+
 =head2 get0_alpn_selected_return_string
 
 C<method get0_alpn_selected_return_string : string ()>
